Class: Google::Type::TimeOfDay
- Inherits:
-
Object
- Object
- Google::Type::TimeOfDay
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/type/timeofday.rb
Overview
Represents a time of day. The date and time zone are either not significant
or are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and
google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ ::Integer
Hours of a day in 24 hour format.
-
#minutes ⇒ ::Integer
Minutes of an hour.
-
#nanos ⇒ ::Integer
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ ::Integer
Seconds of a minute.
Instance Attribute Details
#hours ⇒ ::Integer
Returns Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time.
44 45 46 47 |
# File 'proto_docs/google/type/timeofday.rb', line 44 class TimeOfDay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minutes ⇒ ::Integer
Returns Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59.
44 45 46 47 |
# File 'proto_docs/google/type/timeofday.rb', line 44 class TimeOfDay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#nanos ⇒ ::Integer
Returns Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999.
44 45 46 47 |
# File 'proto_docs/google/type/timeofday.rb', line 44 class TimeOfDay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#seconds ⇒ ::Integer
Returns Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap-seconds.
44 45 46 47 |
# File 'proto_docs/google/type/timeofday.rb', line 44 class TimeOfDay include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |